@@ -371,11 +371,8 @@ class Parser:
         TokenType.PARAMETER: lambda self, _: exp.Parameter(this=self._parse_var() or self._parse_primary()),
         TokenType.BIT_STRING: lambda _, token: exp.BitString(this=token.text),
         TokenType.HEX_STRING: lambda _, token: exp.HexString(this=token.text),
-        TokenType.INTRODUCER: lambda self, token: self.expression(
-            exp.Introducer,
-            this=token.text,
-            expression=self._parse_var_or_string(),
-        ),
+        TokenType.BYTE_STRING: lambda _, token: exp.ByteString(this=token.text),
+        TokenType.INTRODUCER: lambda self, token: self._parse_introducer(token),
     }
 
     RANGE_PARSERS = {
@@ -913,7 +910,7 @@ class Parser:
 
         return self.expression(
             exp.LoadData,
-            this=self._parse_id_var(),
+            this=self._parse_table(schema=True),
             local=local,
             overwrite=overwrite,
             inpath=inpath,
@@ -928,6 +925,7 @@ class Parser:
         return self.expression(
             exp.Delete,
             this=self._parse_table(schema=True),
+            using=self._parse_csv(lambda: self._match(TokenType.USING) and self._parse_table(schema=True)),
             where=self._parse_where(),
         )
 
@@ -1676,6 +1674,11 @@ class Parser:
         is_struct = type_token == TokenType.STRUCT
         expressions = None
 
+        if not nested and self._match_pair(TokenType.L_BRACKET, TokenType.R_BRACKET):
+            return exp.DataType(
+                this=exp.DataType.Type.ARRAY, expressions=[exp.DataType.build(type_token.value)], nested=True
+            )
+
         if self._match(TokenType.L_BRACKET):
             self._retreat(index)
             return None
@@ -1686,7 +1689,7 @@ class Parser:
             elif nested:
                 expressions = self._parse_csv(self._parse_types)
             else:
-                expressions = self._parse_csv(self._parse_type)
+                expressions = self._parse_csv(self._parse_conjunction)
 
             if not expressions:
                 self._retreat(index)
@@ -1871,6 +1874,17 @@ class Parser:
         self._match_r_paren()
         return self.expression(exp.UserDefinedFunction, this=this, expressions=expressions)
 
+    def _parse_introducer(self, token):
+        literal = self._parse_primary()
+        if literal:
+            return self.expression(
+                exp.Introducer,
+                this=token.text,
+                expression=literal,
+            )
+
+        return self.expression(exp.Identifier, this=token.text)
+
     def _parse_udf_kwarg(self):
         this = self._parse_id_var()
         kind = self._parse_types()
